<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation>Kivág (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation>Másol (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation>Beilleszt (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation>Mégse (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation>Újra (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation>Hatvány (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation>Zárójelek (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation>Abszolút érték (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation>Tört (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation>Gyök (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation>{%1}{%2} távolság</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation>{%1} kerülete</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation>{%1} hossza</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation>{%1} sugara</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation>{%1} ív szöge</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation>{%1}{%2}{%3} szög</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation>{%1}:{%2} arány</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation>{%1} meredeksége</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation>{%1} területe</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation>pont</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>szakasz</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation>sugár</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>egyenes</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>kör</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>ív</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>törött vonal</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation>körlemez</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation>körcikk</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation>körtartomány</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation>mértani hely</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation>mérés</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>számítás</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>megjegyzés</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>ismeretlen</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation>határozatlan</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation>Nem meghatározott érték</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation>Az érték %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation>Az %2 %1 megadása</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Kész</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation>Ciklus %1-n</translation>
    </message>
    <message>
        <source>or</source>
        <translation>vagy</translation>
    </message>
    <message>
        <source>final</source>
        <translation>végső</translation>
    </message>
    <message>
        <source>initial</source>
        <translation>kezdeti</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation>nincs megszerkesztve</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation>nem létezik</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation>rejtett</translation>
    </message>
    <message>
        <source>Given</source>
        <translation>Adott</translation>
    </message>
    <message>
        <source>Final</source>
        <translation>Végső</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation>Kezdeti</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 a %2 eltolása a(z) %3%4 vektorral</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation>%1 a %2 elforgatottja %3 körül %4 szöggel</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation>%1 a %2 képe a %3 középpontú, %4:%5 arányú nyújtás mellett</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation>%1 a %2 képe a %3 középpontú, %4 arányú nyújtás mellett</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation>%1 a %2 %3-ra vett tükürképe</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation>%1 szabad</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation>%1 rajta van %2-n</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation>%1 a %2 és %3 metszete</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation type="unfinished">%1 a %2 és %3 második metszéspontja</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation>%1 a %2 középpontja</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 végpontjai %2 és %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation type="unfinished">%1 %2-ból megy %3-n át</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation type="unfinished">%1 felezi a %2 %3 %4 szöget</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation type="unfinished">%1 összeköti %2 és %3 objektumokat</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation type="unfinished">%1 a %3-n keresztüli párhuzamos %2-vel</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation type="unfinished">%1 a %3-ból %2-ra bocsátott merőleges</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation type="unfinished">%1 középpontja %2 és átmegy %3-n</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation type="unfinished">%1 középpontja %2 és sugara %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation type="unfinished">%1 átmegy a %2, %3 és %4 pontokon</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation type="unfinished">%1 is traced by %2, driven by %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 tartalmazza %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation type="unfinished">%1 a %2 és %3 távolsága</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation type="unfinished">%1 a %2 hossza</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation type="unfinished">%1 a %2 szöge</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation type="unfinished">%1 a %1, %2 és %3 pontok által meghatározott szög</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation type="unfinished">%1 a %2 és %3 aránya</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation type="unfinished">%1 a %2 meredeksége</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation type="unfinished">%1 a %2 területe</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation type="unfinished">%1-t %2 definiálja</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation type="unfinished">%1-nak csúcsai vannak a %2 pontokban</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation type="unfinished">%1 a %2 sugara</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Mégse</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation>Kérem a rekurzió mélységét:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation>Túl sok objektumot fog létrehozni.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation>%1 objektumot fog létrehozni.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation>Példák a mértani helyben:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Kész</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation>A(z) %2 %1 címkéjének mozgatása</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation>A(z) %2 %1 kiválasztása</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation>A(z) %2 %1 kiválasztásának törlése</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation>A(z) %2 %1 további kiválasztása</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation>A kiválasztott objektumok mozgatása</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation>A(z) %2 %1 felszabadítása</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation>A(z) %2 %1 kapcsolása %4 %3 objektumhoz</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation>A(z) %4 %3 és %6 %5 metszetének kapcsolása a(z) %2 %1 objektumhoz</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation>kseg: Névtelen</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Kinézet</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Új</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation>&amp;Mérés</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation>&amp;Transzformáció</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation>S&amp;zerkesztés</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Súgó</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation>&amp;Új ábra</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation>Ú&amp;j szerkesztés</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation type="unfinished">Új &amp;nézet</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Megnyit ...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>M&amp;ent</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Men&amp;t másként...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>N&amp;yomtat ...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation>Nye&amp;lv beállítása...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilép</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Visszacsinál</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Újra csinál</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation>&amp;Objektum törlése</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation>&amp;Címkét mutat/rejt</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation>Címke rejtése</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation>Címke mutatása</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation>Cí&amp;mke változtatás...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation>Objektumok &amp;rejtése</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation>M&amp;indet mutat</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Szín</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation>&amp;Vonal és stílus</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation>&amp;Pont stílus</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Betűtípus</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation>Pél&amp;dányok számának változtatása...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation>&amp;Egyéb...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation>&amp;Betűtípus...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation>&amp;Metszéspont</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation>&amp;Szakasz</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation>&amp;Középpont</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation>S&amp;ugár</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation>&amp;Egyenes</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation>Me&amp;rőleges egyenes</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation>Kör középponttal és &amp;ponttal</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation>&amp;Ív három ponttal</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation>Szög&amp;felező</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation>Mértani &amp;hely</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation>S&amp;okszög</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation>Kör&amp;cikk</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation>Kör&amp;tartomány</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation>Kör&amp;lemez</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation>&amp;Távolság</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation>&amp;Hossz</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation>S&amp;ugár</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation>&amp;Szög</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation>A&amp;rány</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation>&amp;Meredekség</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation>Terü&amp;let</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation>&amp;Kiszámít...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation>Válassz &amp;vektort</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation>Válassz &amp;tengelyt</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation>Válassz &amp;centrumot</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation>Válassz &amp;szöget</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation>Válassz &amp;arányt</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation>Választás tö&amp;rlése</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation>&amp;Eltolás</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation>Tü&amp;krözés</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation>&amp;Nagyítás</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation>&amp;Forgatás</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation>Tedd &amp;Rendessé</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation>Tedd &amp;Adottá</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation>Tedd &amp;Végsővé</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation>Tedd &amp;Kezdetivé</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation>R&amp;ekurzió</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation>&amp;Gyors lejátszás</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Névjegy...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation>&amp;Kerület</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation>Ív&amp;hossz</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation>&amp;Címkéket mutat/rejt</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation>Címkék elrejtése</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation>Címkék mutatása</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation>&amp;Szakaszok</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation>&amp;Sugarak</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation>&amp;Középpontok</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation>&amp;Metszéspontok</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation>&amp;Kör középponttal és sugárral</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation>&amp;Egyenesek</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation>&amp;Párhuzamos egyenesek</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation>&amp;Párhuzamos egyenes</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation>&amp;Merőleges egyenesek</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation>&amp;Könyvtár váltás...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation>Nincsenek szerkesztések</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation>Mentés?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation>El akarja menteni a változtatásokat?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>A fájl nem található</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation>Sajnálom, de attól tartok, hogy a %1 fájl nem létezik.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Érvénytelen fájl</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation>A %1 fájl nem úgy néz ki, mint egy érvényes KSEG fájl.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation>Nyelv beállítás</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation>A nyelv beállításakor a teljes hatás eléréséhez újra kell indítania a KSEG-et.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation>KSEG névjegy</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation type="unfinished">KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation>Sorok:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Oszlopok:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation>Nulla-kitöltés</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
</context>
</TS>
